<?php

session_start();

// Initialize an array to store error messages
$errors = [];

if ($_SERVER["REQUEST_METHOD"] == "POST") {

    // Retrieve and trim form inputs
    $firstName   = isset($_POST['firstName']) ? trim($_POST['firstName']) : "";
    $lastName    = isset($_POST['lastName']) ? trim($_POST['lastName']) : "";
    $email       = isset($_POST['email']) ? trim($_POST['email']) : "";
    $isStudent   = isset($_POST['isStudent']) ? $_POST['isStudent'] : "";
    $comments    = isset($_POST['comments']) ? trim($_POST['comments']) : "";
    
    // Bonus: Retrieve date dropdown values
    $birthMonth  = isset($_POST['birthMonth']) ? trim($_POST['birthMonth']) : "";
    $birthDay    = isset($_POST['birthDay']) ? trim($_POST['birthDay']) : "";
    $birthYear   = isset($_POST['birthYear']) ? trim($_POST['birthYear']) : "";
    
    // Bonus: Retrieve checkbox values (areas of interest)
    $interests   = isset($_POST['interests']) ? $_POST['interests'] : array();
    
    // Validate First Name (required text field)
    if (empty($firstName)) {
        $errors[] = "First name is required.";
    }
    
    // Validate Last Name (required text field)
    if (empty($lastName)) {
        $errors[] = "Last name is required.";
    }
    
    // Validate Email (required and must be in a valid format)
    if (empty($email)) {
        $errors[] = "Email is required.";
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $errors[] = "Please enter a valid email address.";
    }
    
    // Validate Student Status (radio button)
    if (empty($isStudent)) {
        $errors[] = "Please select your student status.";
    }
    
    // Validate Comments (required textarea)
    if (empty($comments)) {
        $errors[] = "Comments are required.";
    }
    
    // Bonus: Validate the Date Dropdown (ensure month, day, and year are selected)
    if (empty($birthMonth) || empty($birthDay) || empty($birthYear)) {
        $errors[] = "Birth date (month, day, and year) must be selected.";
    }
    
    // Bonus: Validate that at least one interest checkbox is selected.
    if (empty($interests)) {
        $errors[] = "Please select at least one area of interest.";
    }
    
    // If there are any errors, display them on a separate error page.
    if (!empty($errors)) {
        ?>
        <!DOCTYPE html>
        <html lang="en">
        <head>
            <meta charset="UTF-8">
            <meta name="viewport" content="width=device-width, initial-scale=1.0">
            <title>Form Submission Error</title>
            <style>
                body {
                    background-color: grey;
                    font-family: Arial, sans-serif;
                    margin: 0;
                    padding: 0;
                    display: flex;
                    justify-content: center;
                    align-items: center;
                    height: 100vh;
                }
                .container {
                    width: 50%;
                    background-color: white;
                    padding: 20px;
                    border-radius: 8px;
                    box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
                }
                h1 {
                    text-align: center;
                    color: #333;
                }
                .error {
                    color: red;
                    text-align: center;
                    list-style: none;
                    padding: 0;
                }
                p {
                    text-align: center;
                }
            </style>
        </head>
        <body>
            <div class="container">
                <h1>Submission Errors</h1>
                <ul class="error">
                    <?php foreach ($errors as $error): ?>
                        <li><?php echo $error; ?></li>
                    <?php endforeach; ?>
                </ul>
                <p><a href="index.php">Go back to the form</a></p>
            </div>
        </body>
        </html>
        <?php
        exit();
    } else {
        // No errors: Sanitize data for safe output
        $firstName  = htmlspecialchars($firstName);
        $lastName   = htmlspecialchars($lastName);
        $email      = htmlspecialchars($email);
        $isStudent  = htmlspecialchars($isStudent);
        $comments   = htmlspecialchars($comments);
        
        // Prepare the birth date string
        $birthDate = $birthMonth . " " . $birthDay . ", " . $birthYear;
        
        // Prepare a comma-separated list of interests
        $interestList = implode(', ', $interests);
        ?>
        <!DOCTYPE html>
        <html lang="en">
        <head>
            <meta charset="UTF-8">
            <meta name="viewport" content="width=device-width, initial-scale=1.0">
            <title>Form Submission Confirmation</title>
            <style>
                body {
                    background-color: grey;
                    font-family: Arial, sans-serif;
                    margin: 0;
                    padding: 0;
                    display: flex;
                    justify-content: center;
                    align-items: center;
                    height: 100vh;
                }
                .container {
                    width: 50%;
                    background-color: white;
                    padding: 20px;
                    border-radius: 8px;
                    box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
                }
                h1, h2 {
                    text-align: center;
                    color: #333;
                    margin: 5px 0;
                }
                .confirmation {
                    background: #f0f0f0;
                    padding: 20px;
                    border-radius: 8px;
                    margin-top: 20px;
                }
                .confirmation h3 {
                    color: #333;
                    margin-bottom: 15px;
                }
                .confirmation p {
                    margin: 10px 0;
                }
                .confirmation strong {
                    color: #333;
                }
                .confirmation ul {
                    list-style-type: none;
                    padding: 0;
                }
                .confirmation ul li {
                    margin: 5px 0;
                }
            </style>
        </head>
        <body>
            <div class="container">
                <h1>UWM Information Request Form</h1>
                <h2>Mannan Luo | Assignment 4-5</h2>
                <div class="confirmation">
                    <h3>Thank you, <?php echo $firstName; ?>!</h3>
                    <p>Your form has been submitted successfully. We will contact you via email at <strong><?php echo $email; ?></strong>.</p>
                    <p>The information you submitted is shown below:</p>
                    <ul>
                        <li><strong>First Name:</strong> <?php echo $firstName; ?></li>
                        <li><strong>Last Name:</strong> <?php echo $lastName; ?></li>
                        <li><strong>Email:</strong> <?php echo $email; ?></li>
                        <li><strong>Birth Date:</strong> <?php echo $birthDate; ?></li>
                        <li><strong>UWM Student Status:</strong> <?php echo $isStudent; ?></li>
                        <li><strong>Areas of Interest:</strong> <?php echo $interestList; ?></li>
                        <li><strong>Comments:</strong> <?php echo nl2br($comments); ?></li>
                    </ul>
                </div>
            </div>
        </body>
        </html>
        <?php
    }
} else {
    // If accessed directly without a POST submission, redirect to the form page.
    header("Location: index.php");
    exit();
}
?>
