<?php

// Section 1: PHP Initialization & Form Handling

// Start output buffering and session management
ob_start();
session_start();

// Initialize an array to hold error messages (if any)
$errors = [];

// Check if the form was submitted via POST method
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Include the form handling file to process the form data
    include 'handle_form.php';
}
?>



<!DOCTYPE html>
<!-- Section 2: HTML Head Section (Metadata & Styling) -->

<html lang="en">
<head>
    <!-- Metadata and document title -->
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>UWM Information Request Form</title>
    <!-- Embedded CSS styling -->
    <style>
        /* Style for the entire page */
        body {
            background-color: grey;
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
        }
        /* Container style for centering the form */
        .container {
            width: 50%;
            background-color: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }
        /* Headings styling */
        h1, h2 {
            color: #333;
            text-align: center;
            margin: 5px 0;
        }
        /* Style for form groups (label and input pairs) */
        .form-group {
            display: flex;
            align-items: center;
            margin-bottom: 10px;
        }
        /* Label styling within form groups */
        .form-group label {
            width: 30%;
            text-align: right;
            margin-right: 10px;
        }
        /* Input, select, and textarea styling */
        .form-group input, 
        .form-group select, 
        .form-group textarea {
            width: 70%;
            padding: 8px;
            border: 1px solid #ccc;
            border-radius: 4px;
        }
        /* Styling for the submit button */
        input[type="submit"] {
            background-color: #4CAF50;
            color: white;
            padding: 10px 20px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            margin-top: 10px;
            width: 100%;
        }
        /* Hover effect for the submit button */
        input[type="submit"]:hover {
            background-color: #45a049;
        }
        /* Error message list styling */
        .error {
            color: red;
            text-align: center;
            list-style: none;
            padding: 0;
        }
        /* Styling for the birth date group container */
        .birth-date-group {
            display: flex;
            align-items: center;
            gap: 5px;
        }
        /* Styling for each select element within the birth date group */
        .birth-date-group select {
            padding: 8px;
            border: 1px solid #ccc;
            border-radius: 4px;
        }
        /* Additional styling for radio buttons and checkboxes */
        .radio-group {
            display: flex;
            align-items: center;
            gap: 15px;
        }
        /* Style for each radio button option */
        .radio-option {
            display: flex;
            align-items: center;
            gap: 5px;
            flex-direction: row-reverse;
        }
        /* Style for each checkbox option */
        .checkbox-option {
            display: flex;
            align-items: center;
            gap: 5px;
            flex-direction: row-reverse;
            margin-bottom: 8px;
        }
        /* Container for grouping checkbox options */
        .options-group {
            margin-left: 30%;
        }
        /* Style for the pipe separator between radio options */
        .pipe-separator {
            color: #666;
            padding: 0 5px;
        }
    </style>
</head>

<!--Section 3: HTML Body Section (Container, Header, and Error Display)-->
<body>
    <!-- Main container for the form -->
    <div class="container">
        <!-- Include the header content (header_form.php) -->
        <?php include 'header_form.php'; ?>

        <!-- Main page headings -->
        <h1>UWM Information Request Form</h1>
        <h2>Shiva Botta | Assignment 4-5</h2>

        <!-- Display any error messages if they exist -->
        <?php if (!empty($errors)): ?>
            <ul class="error">
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        <?php endif; ?>
        
    <!--Section 4 : The form and fields-->

        <!-- Start of the form -->
        <form action="handle_form.php" method="post">
            <fieldset>
                <!-- Fieldset legend describing the purpose of the form -->
                <legend>Enter your information in the form below to complete registration:</legend>

                <!-- First Name Field -->
                <div class="form-group">
                    <!-- Label for first name -->
                    <label for="firstName">First Name:</label>
                    <!-- Text input for first name; value is repopulated if form is submitted -->
                    <input type="text" id="firstName" name="firstName" 
                           value="<?php echo isset($_POST['firstName']) ? htmlspecialchars($_POST['firstName']) : ''; ?>" 
                           required placeholder="Enter your first name">
                </div>

                <!-- Last Name Field -->
                <div class="form-group">
                    <!-- Label for last name -->
                    <label for="lastName">Last Name:</label>
                    <!-- Text input for last name; value is repopulated if form is submitted -->
                    <input type="text" id="lastName" name="lastName" 
                           value="<?php echo isset($_POST['lastName']) ? htmlspecialchars($_POST['lastName']) : ''; ?>" 
                           required placeholder="Enter your last name">
                </div>

                <!-- Email Field -->
                <div class="form-group">
                    <!-- Label for email -->
                    <label for="email">Email:</label>
                    <!-- Email input; prepopulated with default email if not set -->
                    <input type="email" id="email" name="email" 
                           value="<?php echo isset($_POST['email']) ? htmlspecialchars($_POST['email']) : 'xyz@uwm.edu'; ?>" 
                           required>
                </div>

                <!-- Birth Date Section -->
                <div class="form-group">
                    <!-- Label for birth date -->
                    <label for="birthMonth">Birth Date:</label>
                    <!-- Container for the three date dropdowns -->
                    <div class="birth-date-group">
                        <!-- Month Dropdown -->
                        <select id="birthMonth" name="birthMonth" required>
                            <?php
                            // Create an array of month names
                            $months = ['January', 'February', 'March', 'April', 'May', 'June', 
                                      'July', 'August', 'September', 'October', 'November', 'December'];
                            // Retrieve the previously selected month or default to 'January'
                            $selectedMonth = isset($_POST['birthMonth']) ? $_POST['birthMonth'] : 'January';
                            // Loop through the months array and generate an option for each month
                            foreach ($months as $month) {
                                // Check if this month should be the selected option
                                $selected = ($month == $selectedMonth) ? 'selected' : '';
                                echo "<option value=\"$month\" $selected>$month</option>";
                            }
                            ?>
                        </select>
                        <!-- Day Dropdown -->
                        <select id="birthDay" name="birthDay" required>
                            <?php
                            // Retrieve the previously selected day or default to 1
                            $selectedDay = isset($_POST['birthDay']) ? $_POST['birthDay'] : '1';
                            // Loop from 1 to 31 to generate day options
                            for ($day = 1; $day <= 31; $day++) {
                                // Check if this day should be the selected option
                                $selected = ($day == $selectedDay) ? 'selected' : '';
                                echo "<option value=\"$day\" $selected>$day</option>";
                            }
                            ?>
                        </select>
                        <!-- Year Dropdown -->
                        <select id="birthYear" name="birthYear" required>
                            <?php
                            // Get the current year and determine the starting year (current year minus 100)
                            $currentYear = date("Y");
                            $startYear = $currentYear - 100;
                            // Retrieve the previously selected year or default to 2004
                            $selectedYear = isset($_POST['birthYear']) ? $_POST['birthYear'] : '2004';
                            // Loop from the current year down to the start year to generate year options
                            for ($year = $currentYear; $year >= $startYear; $year--) {
                                // Check if this year should be selected
                                $selected = ($year == $selectedYear) ? 'selected' : '';
                                echo "<option value=\"$year\" $selected>$year</option>";
                            }
                            ?>
                        </select>
                    </div>
                </div>

                <!-- Student Status Radio Buttons -->
                <div class="form-group">
                    <!-- Label for student status question -->
                    <label>Are you a student at UWM?</label>
                    <div class="radio-group">
                        <!-- Radio button option for "Yes" -->
                        <div class="radio-option">
                            <label for="isStudentYes">Yes</label>
                            <input type="radio" id="isStudentYes" name="isStudent" value="Yes" 
                                <?php echo (isset($_POST['isStudent']) && $_POST['isStudent'] == 'Yes') ? 'checked' : ''; ?>>
                        </div>
                        <!-- Visual separator between radio options -->
                        <span class="pipe-separator">|</span>
                        <!-- Radio button option for "No" -->
                        <div class="radio-option">
                            <label for="isStudentNo">No</label>
                            <input type="radio" id="isStudentNo" name="isStudent" value="No" 
                                <?php echo (!isset($_POST['isStudent']) || (isset($_POST['isStudent']) && $_POST['isStudent'] == 'No')) ? 'checked' : ''; ?>>
                        </div>
                    </div>
                </div>

                <!-- Areas of Interest Checkboxes -->
                <div class="form-group">
                    <!-- Label for interests -->
                    <label>What areas are you interested in?</label>
                    <div class="options-group">
                        <!-- Checkbox for Information Technology -->
                        <div class="checkbox-option">
                            <label for="interestIT">Information Technology</label>
                            <input type="checkbox" id="interestIT" name="interests[]" value="Information Technology">
                        </div>
                        <!-- Checkbox for History -->
                        <div class="checkbox-option">
                            <label for="interestHistory">History</label>
                            <input type="checkbox" id="interestHistory" name="interests[]" value="History">
                        </div>
                        <!-- Checkbox for Math -->
                        <div class="checkbox-option">
                            <label for="interestMath">Math</label>
                            <input type="checkbox" id="interestMath" name="interests[]" value="Math">
                        </div>
                    </div>
                </div>

                <!-- Comments Text Area -->
                <div class="form-group">
                    <label for="comments">Please enter some comments:</label>
                    <textarea id="comments" name="comments" rows="4" cols="50">
                        <?php 
                        // Display the previously submitted comment or a default comment prompt
                        echo isset($_POST['comments']) ? htmlspecialchars($_POST['comments']) : 'Question about transferring to UWM.'; 
                        ?>
                    </textarea>
                </div>

                <!-- Submit Button -->
                <input type="submit" value="Submit">
            </fieldset>
        </form>
<!--Section 5: Footer Inclusion & Closing Tags-->
        <!-- Include the footer content (footer.php) -->
        <?php include 'footer.php'; ?>
    </div>
</body>
</html>

<!--
Section 1: PHP Initialization & Form Handling
PHP Manual – session_start: https://www.php.net/manual/en/function.session-start.php
PHP Manual – ob_start: https://www.php.net/manual/en/function.ob-start.php
PHP Reserved Variables – $_SERVER: https://www.php.net/manual/en/reserved.variables.server.php
PHP Manual – include: https://www.php.net/manual/en/function.include.php


Section 2: HTML Head Section (Metadata & Styling)
HTML5 Specification – W3C HTML5: https://www.w3.org/TR/html52/
MDN Web Docs – HTML Basics: https://developer.mozilla.org/en-US/docs/Web/HTML
MDN Web Docs – CSS Basics: https://developer.mozilla.org/en-US/docs/Web/CSS


Section 3: HTML Body Section (Container, Header, and Error Display)
PHP Manual – include: https://www.php.net/manual/en/function.include.php
MDN Web Docs – HTML Lists: https://developer.mozilla.org/en-US/docs/Web/HTML/Element/ul


Section 4: The Form & Its Fields
MDN Web Docs – HTML Forms: https://developer.mozilla.org/en-US/docs/Learn/Forms
PHP Manual – htmlspecialchars: https://www.php.net/manual/en/function.htmlspecialchars.php
MDN Web Docs – HTML Input Element: https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input


Section 5: Footer Inclusion & Closing Tags
PHP Manual – include: https://www.php.net/manual/en/function.include.php
MDN Web Docs – HTML Basics: https://developer.mozilla.org/en-US/docs/Web/HTML
-->

